==> chaosmesh-model-5.0.3-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.lang.Integer;
import java.lang.StringBuffer;

public interface NetworkChaosSpecFluent<A extends NetworkChaosSpecFluent<A>> extends Fluent<A> {


    public String getAction();
    public A withAction(String action);
    public Boolean hasAction();
    public A withNewAction(String arg1);
    public A withNewAction(StringBuilder arg1);
    public A withNewAction(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildBandwidth instead.
 * @return The buildable object.
 */
@Deprecated public BandwidthSpec getBandwidth();
    public BandwidthSpec buildBandwidth();
    public A withBandwidth(BandwidthSpec bandwidth);
    public Boolean hasBandwidth();
    public A withNewBandwidth(Integer buffer,Integer limit,Long minburst,Long peakrate,String rate);
    public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidth();
    public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidthLike(BandwidthSpec item);
    public NetworkChaosSpecFluent.BandwidthNested<A> editBandwidth();
    public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidth();
    public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidthLike(BandwidthSpec item);
    
/**
 * This method has been deprecated, please use method buildCorrupt instead.
 * @return The buildable object.
 */
@Deprecated public CorruptSpec getCorrupt();
    public CorruptSpec buildCorrupt();
    public A withCorrupt(CorruptSpec corrupt);
    public Boolean hasCorrupt();
    public A withNewCorrupt(String correlation,String corrupt);
    public NetworkChaosSpecFluent.CorruptNested<A> withNewCorrupt();
    public NetworkChaosSpecFluent.CorruptNested<A> withNewCorruptLike(CorruptSpec item);
    public NetworkChaosSpecFluent.CorruptNested<A> editCorrupt();
    public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorrupt();
    public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorruptLike(CorruptSpec item);
    
/**
 * This method has been deprecated, please use method buildDelay instead.
 * @return The buildable object.
 */
@Deprecated public DelaySpec getDelay();
    public DelaySpec buildDelay();
    public A withDelay(DelaySpec delay);
    public Boolean hasDelay();
    public NetworkChaosSpecFluent.DelayNested<A> withNewDelay();
    public NetworkChaosSpecFluent.DelayNested<A> withNewDelayLike(DelaySpec item);
    public NetworkChaosSpecFluent.DelayNested<A> editDelay();
    public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelay();
    public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelayLike(DelaySpec item);
    public String getDirection();
    public A withDirection(String direction);
    public Boolean hasDirection();
    public A withNewDirection(String arg1);
    public A withNewDirection(StringBuilder arg1);
    public A withNewDirection(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDuplicate instead.
 * @return The buildable object.
 */
@Deprecated public DuplicateSpec getDuplicate();
    public DuplicateSpec buildDuplicate();
    public A withDuplicate(DuplicateSpec duplicate);
    public Boolean hasDuplicate();
    public A withNewDuplicate(String correlation,String duplicate);
    public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicate();
    public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicateLike(DuplicateSpec item);
    public NetworkChaosSpecFluent.DuplicateNested<A> editDuplicate();
    public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicate();
    public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicateLike(DuplicateSpec item);
    public String getDuration();
    public A withDuration(String duration);
    public Boolean hasDuration();
    public A withNewDuration(String arg1);
    public A withNewDuration(StringBuilder arg1);
    public A withNewDuration(StringBuffer arg1);
    public A addToExternalTargets(int index,String item);
    public A setToExternalTargets(int index,String item);
    public A addToExternalTargets(String... items);
    public A addAllToExternalTargets(Collection<String> items);
    public A removeFromExternalTargets(String... items);
    public A removeAllFromExternalTargets(Collection<String> items);
    public List<String> getExternalTargets();
    public String getExternalTarget(int index);
    public String getFirstExternalTarget();
    public String getLastExternalTarget();
    public String getMatchingExternalTarget(Predicate<String> predicate);
    public Boolean hasMatchingExternalTarget(Predicate<String> predicate);
    public A withExternalTargets(List<String> externalTargets);
    public A withExternalTargets(String... externalTargets);
    public Boolean hasExternalTargets();
    public A addNewExternalTarget(String arg1);
    public A addNewExternalTarget(StringBuilder arg1);
    public A addNewExternalTarget(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildLoss instead.
 * @return The buildable object.
 */
@Deprecated public LossSpec getLoss();
    public LossSpec buildLoss();
    public A withLoss(LossSpec loss);
    public Boolean hasLoss();
    public A withNewLoss(String correlation,String loss);
    public NetworkChaosSpecFluent.LossNested<A> withNewLoss();
    public NetworkChaosSpecFluent.LossNested<A> withNewLossLike(LossSpec item);
    public NetworkChaosSpecFluent.LossNested<A> editLoss();
    public NetworkChaosSpecFluent.LossNested<A> editOrNewLoss();
    public NetworkChaosSpecFluent.LossNested<A> editOrNewLossLike(LossSpec item);
    public String getMode();
    public A withMode(String mode);
    public Boolean hasMode();
    public A withNewMode(String arg1);
    public A withNewMode(StringBuilder arg1);
    public A withNewMode(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public SchedulerSpec getScheduler();
    public SchedulerSpec buildScheduler();
    public A withScheduler(SchedulerSpec scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String cron);
    public NetworkChaosSpecFluent.SchedulerNested<A> withNewScheduler();
    public NetworkChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item);
    public NetworkChaosSpecFluent.SchedulerNested<A> editScheduler();
    public NetworkChaosSpecFluent.SchedulerNested<A> editOrNewScheduler();
    public NetworkChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public SelectorSpec getSelector();
    public SelectorSpec buildSelector();
    public A withSelector(SelectorSpec selector);
    public Boolean hasSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> withNewSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item);
    public NetworkChaosSpecFluent.SelectorNested<A> editSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item);
    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public Target getTarget();
    public Target buildTarget();
    public A withTarget(Target target);
    public Boolean hasTarget();
    public NetworkChaosSpecFluent.TargetNested<A> withNewTarget();
    public NetworkChaosSpecFluent.TargetNested<A> withNewTargetLike(Target item);
    public NetworkChaosSpecFluent.TargetNested<A> editTarget();
    public NetworkChaosSpecFluent.TargetNested<A> editOrNewTarget();
    public NetworkChaosSpecFluent.TargetNested<A> editOrNewTargetLike(Target item);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(String arg1);
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(StringBuffer arg1);
    public interface BandwidthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BandwidthSpecFluent<NetworkChaosSpecFluent.BandwidthNested<N>> {

            public N and();
            public N endBandwidth();    }


    public interface CorruptNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CorruptSpecFluent<NetworkChaosSpecFluent.CorruptNested<N>> {

            public N and();
            public N endCorrupt();    }


    public interface DelayNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DelaySpecFluent<NetworkChaosSpecFluent.DelayNested<N>> {

            public N and();
            public N endDelay();    }


    public interface DuplicateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DuplicateSpecFluent<NetworkChaosSpecFluent.DuplicateNested<N>> {

            public N and();
            public N endDuplicate();    }


    public interface LossNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LossSpecFluent<NetworkChaosSpecFluent.LossNested<N>> {

            public N and();
            public N endLoss();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SchedulerSpecFluent<NetworkChaosSpecFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SelectorSpecFluent<NetworkChaosSpecFluent.SelectorNested<N>> {

            public N and();
            public N endSelector();    }


    public interface TargetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetFluent<NetworkChaosSpecFluent.TargetNested<N>> {

            public N and();
            public N endTarget();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/NetworkChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.lang.Integer;
import java.lang.StringBuffer;

public interface NetworkChaosSpecFluent<A extends NetworkChaosSpecFluent<A>> extends Fluent<A> {


    public String getAction();
    public A withAction(String action);
    public Boolean hasAction();
    public A withNewAction(StringBuilder arg1);
    public A withNewAction(int[] arg1,int arg2,int arg3);
    public A withNewAction(char[] arg1);
    public A withNewAction(StringBuffer arg1);
    public A withNewAction(byte[] arg1,int arg2);
    public A withNewAction(byte[] arg1);
    public A withNewAction(char[] arg1,int arg2,int arg3);
    public A withNewAction(byte[] arg1,int arg2,int arg3);
    public A withNewAction(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewAction(String arg1);
    
/**
 * This method has been deprecated, please use method buildBandwidth instead.
 * @return The buildable object.
 */
@Deprecated public BandwidthSpec getBandwidth();
    public BandwidthSpec buildBandwidth();
    public A withBandwidth(BandwidthSpec bandwidth);
    public Boolean hasBandwidth();
    public A withNewBandwidth(Integer buffer,Integer limit,Long minburst,Long peakrate,String rate);
    public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidth();
    public NetworkChaosSpecFluent.BandwidthNested<A> withNewBandwidthLike(BandwidthSpec item);
    public NetworkChaosSpecFluent.BandwidthNested<A> editBandwidth();
    public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidth();
    public NetworkChaosSpecFluent.BandwidthNested<A> editOrNewBandwidthLike(BandwidthSpec item);
    
/**
 * This method has been deprecated, please use method buildCorrupt instead.
 * @return The buildable object.
 */
@Deprecated public CorruptSpec getCorrupt();
    public CorruptSpec buildCorrupt();
    public A withCorrupt(CorruptSpec corrupt);
    public Boolean hasCorrupt();
    public A withNewCorrupt(String correlation,String corrupt);
    public NetworkChaosSpecFluent.CorruptNested<A> withNewCorrupt();
    public NetworkChaosSpecFluent.CorruptNested<A> withNewCorruptLike(CorruptSpec item);
    public NetworkChaosSpecFluent.CorruptNested<A> editCorrupt();
    public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorrupt();
    public NetworkChaosSpecFluent.CorruptNested<A> editOrNewCorruptLike(CorruptSpec item);
    
/**
 * This method has been deprecated, please use method buildDelay instead.
 * @return The buildable object.
 */
@Deprecated public DelaySpec getDelay();
    public DelaySpec buildDelay();
    public A withDelay(DelaySpec delay);
    public Boolean hasDelay();
    public NetworkChaosSpecFluent.DelayNested<A> withNewDelay();
    public NetworkChaosSpecFluent.DelayNested<A> withNewDelayLike(DelaySpec item);
    public NetworkChaosSpecFluent.DelayNested<A> editDelay();
    public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelay();
    public NetworkChaosSpecFluent.DelayNested<A> editOrNewDelayLike(DelaySpec item);
    public String getDirection();
    public A withDirection(String direction);
    public Boolean hasDirection();
    public A withNewDirection(StringBuilder arg1);
    public A withNewDirection(int[] arg1,int arg2,int arg3);
    public A withNewDirection(char[] arg1);
    public A withNewDirection(StringBuffer arg1);
    public A withNewDirection(byte[] arg1,int arg2);
    public A withNewDirection(byte[] arg1);
    public A withNewDirection(char[] arg1,int arg2,int arg3);
    public A withNewDirection(byte[] arg1,int arg2,int arg3);
    public A withNewDirection(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDirection(String arg1);
    
/**
 * This method has been deprecated, please use method buildDuplicate instead.
 * @return The buildable object.
 */
@Deprecated public DuplicateSpec getDuplicate();
    public DuplicateSpec buildDuplicate();
    public A withDuplicate(DuplicateSpec duplicate);
    public Boolean hasDuplicate();
    public A withNewDuplicate(String correlation,String duplicate);
    public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicate();
    public NetworkChaosSpecFluent.DuplicateNested<A> withNewDuplicateLike(DuplicateSpec item);
    public NetworkChaosSpecFluent.DuplicateNested<A> editDuplicate();
    public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicate();
    public NetworkChaosSpecFluent.DuplicateNested<A> editOrNewDuplicateLike(DuplicateSpec item);
    public String getDuration();
    public A withDuration(String duration);
    public Boolean hasDuration();
    public A withNewDuration(StringBuilder arg1);
    public A withNewDuration(int[] arg1,int arg2,int arg3);
    public A withNewDuration(char[] arg1);
    public A withNewDuration(StringBuffer arg1);
    public A withNewDuration(byte[] arg1,int arg2);
    public A withNewDuration(byte[] arg1);
    public A withNewDuration(char[] arg1,int arg2,int arg3);
    public A withNewDuration(byte[] arg1,int arg2,int arg3);
    public A withNewDuration(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewDuration(String arg1);
    public A addToExternalTargets(int index,String item);
    public A setToExternalTargets(int index,String item);
    public A addToExternalTargets(String... items);
    public A addAllToExternalTargets(Collection<String> items);
    public A removeFromExternalTargets(String... items);
    public A removeAllFromExternalTargets(Collection<String> items);
    public List<String> getExternalTargets();
    public String getExternalTarget(int index);
    public String getFirstExternalTarget();
    public String getLastExternalTarget();
    public String getMatchingExternalTarget(Predicate<String> predicate);
    public Boolean hasMatchingExternalTarget(Predicate<String> predicate);
    public A withExternalTargets(List<String> externalTargets);
    public A withExternalTargets(String... externalTargets);
    public Boolean hasExternalTargets();
    public A addNewExternalTarget(StringBuilder arg1);
    public A addNewExternalTarget(int[] arg1,int arg2,int arg3);
    public A addNewExternalTarget(char[] arg1);
    public A addNewExternalTarget(StringBuffer arg1);
    public A addNewExternalTarget(byte[] arg1,int arg2);
    public A addNewExternalTarget(byte[] arg1);
    public A addNewExternalTarget(char[] arg1,int arg2,int arg3);
    public A addNewExternalTarget(byte[] arg1,int arg2,int arg3);
    public A addNewExternalTarget(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewExternalTarget(String arg1);
    
/**
 * This method has been deprecated, please use method buildLoss instead.
 * @return The buildable object.
 */
@Deprecated public LossSpec getLoss();
    public LossSpec buildLoss();
    public A withLoss(LossSpec loss);
    public Boolean hasLoss();
    public A withNewLoss(String correlation,String loss);
    public NetworkChaosSpecFluent.LossNested<A> withNewLoss();
    public NetworkChaosSpecFluent.LossNested<A> withNewLossLike(LossSpec item);
    public NetworkChaosSpecFluent.LossNested<A> editLoss();
    public NetworkChaosSpecFluent.LossNested<A> editOrNewLoss();
    public NetworkChaosSpecFluent.LossNested<A> editOrNewLossLike(LossSpec item);
    public String getMode();
    public A withMode(String mode);
    public Boolean hasMode();
    public A withNewMode(StringBuilder arg1);
    public A withNewMode(int[] arg1,int arg2,int arg3);
    public A withNewMode(char[] arg1);
    public A withNewMode(StringBuffer arg1);
    public A withNewMode(byte[] arg1,int arg2);
    public A withNewMode(byte[] arg1);
    public A withNewMode(char[] arg1,int arg2,int arg3);
    public A withNewMode(byte[] arg1,int arg2,int arg3);
    public A withNewMode(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMode(String arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public SchedulerSpec getScheduler();
    public SchedulerSpec buildScheduler();
    public A withScheduler(SchedulerSpec scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String cron);
    public NetworkChaosSpecFluent.SchedulerNested<A> withNewScheduler();
    public NetworkChaosSpecFluent.SchedulerNested<A> withNewSchedulerLike(SchedulerSpec item);
    public NetworkChaosSpecFluent.SchedulerNested<A> editScheduler();
    public NetworkChaosSpecFluent.SchedulerNested<A> editOrNewScheduler();
    public NetworkChaosSpecFluent.SchedulerNested<A> editOrNewSchedulerLike(SchedulerSpec item);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public SelectorSpec getSelector();
    public SelectorSpec buildSelector();
    public A withSelector(SelectorSpec selector);
    public Boolean hasSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> withNewSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> withNewSelectorLike(SelectorSpec item);
    public NetworkChaosSpecFluent.SelectorNested<A> editSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelector();
    public NetworkChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(SelectorSpec item);
    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public Target getTarget();
    public Target buildTarget();
    public A withTarget(Target target);
    public Boolean hasTarget();
    public NetworkChaosSpecFluent.TargetNested<A> withNewTarget();
    public NetworkChaosSpecFluent.TargetNested<A> withNewTargetLike(Target item);
    public NetworkChaosSpecFluent.TargetNested<A> editTarget();
    public NetworkChaosSpecFluent.TargetNested<A> editOrNewTarget();
    public NetworkChaosSpecFluent.TargetNested<A> editOrNewTargetLike(Target item);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
    public interface BandwidthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BandwidthSpecFluent<NetworkChaosSpecFluent.BandwidthNested<N>> {

            public N and();
            public N endBandwidth();    }


    public interface CorruptNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CorruptSpecFluent<NetworkChaosSpecFluent.CorruptNested<N>> {

            public N and();
            public N endCorrupt();    }


    public interface DelayNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DelaySpecFluent<NetworkChaosSpecFluent.DelayNested<N>> {

            public N and();
            public N endDelay();    }


    public interface DuplicateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DuplicateSpecFluent<NetworkChaosSpecFluent.DuplicateNested<N>> {

            public N and();
            public N endDuplicate();    }


    public interface LossNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LossSpecFluent<NetworkChaosSpecFluent.LossNested<N>> {

            public N and();
            public N endLoss();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SchedulerSpecFluent<NetworkChaosSpecFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SelectorSpecFluent<NetworkChaosSpecFluent.SelectorNested<N>> {

            public N and();
            public N endSelector();    }


    public interface TargetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetFluent<NetworkChaosSpecFluent.TargetNested<N>> {

            public N and();
            public N endTarget();    }


}
